from bs4 import BeautifulSoup
import requests
from .settings import FEED_URL

NAME_CLASS = "d_mB d_mI"
TEMPERATURE_CLASS = "d_mC"
CONTAINER_CLASS = "d_mG"


class Weather:
    @staticmethod
    def _parse_result(html):
        soup = BeautifulSoup(html, "html.parser")
        items = soup.findAll("div", {"class": CONTAINER_CLASS})

        data = []
        for item in items:
            name = item.find("span", {"class": NAME_CLASS}).text
            temperature = item.find("span", {"class": TEMPERATURE_CLASS}).text
            svg = item.find("svg", {"class": "atm-icon d_mE atm-icon d_mE"})

            data.append({
                'name': name,
                'temperature': temperature,
                'svg': svg
            })

        return {
            'data': data
        }

    def get(self):

        response = requests.get(FEED_URL)
        if response.status_code != 200:
            return {
                'error': 'Oops! Some error from feed source'
            }

        # Parsing process start
        return self._parse_result(response.content)
